@@ -1,14 +1,17 @@
 """A collection of useful tools!"""
 import sys
 
-__version__ = "0.3.14"
+__version__ = "1.0.9"
 
-help_doc_str = """usage: hello [--version] [--help]
+help_doc_str = """\
+usage: hello [--version] [--help]
 
 shell command:
     hello -h
     hello-data -h
     hello-fiftyone -h
+    hello-mmdet -h
+    hello-mmseg -h
     hello-video -h
     hello-x3m -h
 
